# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ansys', 'ansys.tools.repo_sync']

package_data = \
{'': ['*']}

install_requires = \
['pre-commit>=2.15.0,<3.0.0', 'pygithub==1.55']

extras_require = \
{':python_version < "3.8"': ['importlib-metadata>=4.0,<5.0']}

setup_kwargs = {
    'name': 'ansys-tools-repo-sync',
    'version': '0.1.2',
    'description': 'Synchronize the content of two different repositories.',
    'long_description': '*********************\nansys-tools-repo-sync\n*********************\n\nThe ``ansys-tools-repo-sync`` library is intended to synchronize the content\nof two different repositories.\n\nWhat does this library do?\n~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nFor instance, due to intellectual properties concerns, it might not be possible\nto expose publicly the entire content of a private repository.\nIts owner could decide to have a second repository, a public one.\nPart of the content for this public repo would come from the private repository.\n\n``ansys-tools-repo-sync`` allows you to do so by copying a folder and its content\nfrom one repo to the other.\nIn addition, it is possible to filter the type extension file authorized to be copied.\n\n.. image:: doc/images/repo_sync.png\n    :align: center\n\n\nHow to use it?\n~~~~~~~~~~~~~~\n\nA common usage for this tool consist to integrate it in one of your CI/CD pipeline or workflow.\nFirstly, the tool must be installed.\n\n.. code:: yaml\n\n    pip install ansys.tools.repo.synchronize\n\n\nThen, it can be used in the considered workflow with the appropriate arguments.\n\n\n.. code:: yaml\n\n    pip install ansys-tools-repo-sync\n\n\nRun it as follow:\n\n.. code:: yaml\n\n    python -c "from ansys.tools.repo_sync import synchronize"; synchronize(\n    manifest=os.path.join(ASSETS_DIRECTORY, "manifest.txt"),\n    token=TOKEN,\n    repository="ansys-tools-repo-sync",\n    organization="ansys",\n    protos_path=os.path.join("assets", "ansys", "api", "test", "v0"),\n    dry_run=True,\n    )"\n\n.. note::\n    The parameter ``dry_run`` can be set to ``True`` while establishing\n    the entire workflow for the first time. It helps preventing uncessary commits\n    of sensitive data. It will print the content expected to be committed in the\n    public repository.\n\nIssues\n------\nTo post issues, questions, and code, go to `ansys-tools-repo-sync Issues\n<https://github.com/ansys/ansys-tools-repo-sync/issues>`_.\n\n\n\nLicense\n-------\n``ansys-tools-repo-sync`` is licensed under the MIT license.',
    'author': 'ANSYS, Inc.',
    'author_email': None,
    'maintainer': 'PyAnsys developers',
    'maintainer_email': 'pyansys.support@ansys.com',
    'url': 'https://github.com/ansys/ansys-tools-repo-sync',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)
